# TAssist
A python wrapper for the TA Public API (2.0) by Pegasis: https://api.pegasis.site/docs/ta_public_api/

This python package is made to provide some useful functionality alongside mapping the API responses to python objects such as generating mark graphs, tables and more.
This is an unofficial wrapper/project.

Installing
==========
To install you'll need to use Python 3.5+ and the following command:  
`pip install TAssist`  

Usage
-----
```python
import TAssist

```
